## Pre-requisite
- Python >= 3.8
- virtualenv

## Create environments (venv) 
```
git clone https://git.dev.somapait.com/ai-chatbot/project-template/ai-api-python.git
cd ai-api-python
python -m virtualenv venv
.\venv\scripts\activate
pip install -r requirements.txt
```